@@ -426,7 +426,7 @@ void gen_prob_vector(int node, SEXP parlist, int paridx, SEXP catlist, SEXP prob
 	if(paridx >= length(parlist)) {
 		pcats = VECTOR_ELT(catlist, node);
 		if (length(problist) != length(pcats)) {
-			printf("gen_prob_vector: %d:  %d, %d\n", node, length(problist), length(pcats));
+			Rprintf("gen_prob_vector: %d:  %d, %d\n", node, length(problist), length(pcats));
 			error("Wrong probability table");
 			return;
 		}
@@ -447,7 +447,7 @@ void gen_prob_vector(int node, SEXP parlist, int paridx, SEXP catlist, SEXP prob
 	npar = INTEGER_POINTER(parlist)[paridx] - 1;
 	pcats = VECTOR_ELT(catlist, npar);
 	if (length(problist) != length(pcats)) {
-		printf("gen_prob_vector: %d:  %d, %d\n", node, length(problist), length(pcats));
+		Rprintf("gen_prob_vector: %d:  %d, %d\n", node, length(problist), length(pcats));
 		error("Wrong probability table");
 		return;
 	}
@@ -588,7 +588,6 @@ SEXP RCatnet::genSamples(SEXP rNumSamples, SEXP rPerturbations, SEXP rNaRate) {
 				if(nnode >= 0 && nnode < m_numNodes) {
 					paux[nnode] = -(int)RAND_MAX;
 					pSamples[j * m_numNodes + nnode] = R_NaInt;
-//printf("[%d, %d] = NA\n", j, nnode);
 				}
 			}
 		}
